@@ -3,15 +3,15 @@ from airflow.sensors.external_task import ExternalTaskSensor, ExternalTaskMarker
 
 def edge_to(child_id):
     child_name = ".".join(child_id.split(".")[-2:])
-    return f"--NOTIFY--{child_name}"
+    return f"NOTIFY--{child_name}"
 
 
 def edge_from(parent_id):
     parent_name = ".".join(parent_id.split(".")[-2:])
-    return f"--WAIT_FOR--{parent_name}"
+    return f"WAIT_FOR--{parent_name}"
 
 
-def subscribe_to(dag_id, parent_dag_ids, timeout=600, allowed_states=['success'], failed_states=['failed', 'skipped'],
+def subscribe_to(dag_id, parent_dag_ids, timeout=3600, allowed_states=['success'], failed_states=['failed', 'skipped'],
                  mode="reschedule"):
     tasks = []
     for parent_id in parent_dag_ids:
